@@ -1,7 +1,7 @@
 package App::hr;
 
-our $DATE = '2015-08-26'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-12-28'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -28,7 +28,9 @@ sub pick {
 
 
 my $term_width;
-if (eval { require Term::Size; 1 }) {
+if (defined $ENV{COLUMNS}) {
+    $term_width = $ENV{COLUMNS};
+} elsif (eval { require Term::Size; 1 }) {
     ($term_width, undef) = Term::Size::chars();
 } else {
     $term_width = 80;
@@ -217,7 +219,7 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.23 of App::hr (from Perl distribution App-hr), released on 2015-08-26.
+This document describes version 0.24 of App::hr (from Perl distribution App-hr), released on 2015-12-28.
 
 =head1 SYNOPSIS
 
@@ -302,6 +304,8 @@ Usage:
 
 If you use Perl, you can also use the C<hr> function in C<App::hr> module.
 
+This function is not exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
